--------------------------
--    (c) Copyright IBM Corp. 2011, 2013 All rights reserved.
--    InfoSphere Optim Query Workload Tuner Version 4.1.0.1 for DB2 for Linux, UNIX, and Windows
--    
-- If you want to create these objects in a tablespace, follow these steps:
-- 1. Remove "--" from the beginning of line 13 and replace the
--    CREATE TABLESPACE statement with your own.
-- 2. Search for instances of &tablespace and replace them with the 
--    name of your table space.
-- 3. Remove "--" from each CREATE TABLE statement.
-- If your database is v10.5, uncomment the lines with "ORGANIZE BY ROW"

-- CREATE TABLESPACE &tablespace; 

SET CURRENT SCHEMA SYSTOOLS;

DROP TABLE QT_WAPC_SESSIONS_RESULT;
DROP TABLE QT_WAPC_SESSION_EXCEPTIONS;
DROP TABLE QT_WAPC_SESSIONS;
DROP TABLE QT_WCC_WORKLOAD_SOURCE;
DROP TABLE QT_WCC_WORKLOAD_SOURCE_FILTER;
DROP TABLE QT_WCC_WORKLOAD_TASK;
DROP TABLE QT_WCC_EVENT_HISTORY;
DROP TABLE QT_WCC_ERROR_MESSAGE;
DROP TABLE QT_WCC_STMT_INSTANCE;
DROP TABLE QT_WCC_STMT_TEXT;
DROP TABLE QT_WCC_STMT_EXPLAIN_INFO;
DROP TABLE QT_WCC_WORKLOAD_ADVISOR_INFO;
DROP TABLE QT_WCC_STMT_RUNTIME_METRICS;
DROP TABLE QT_WCC_TEMP_CAPTURE;
DROP TABLE QT_WCC_TEMP_EXPLAIN_HANDLE;
DROP TABLE QT_WCC_STMT_DEPENDENT_OBJECT;
DROP SEQUENCE QT_WCC_TUNING_BATCH_ID;
DROP TABLE QT_WCC_WORKLOAD;
DROP TABLE QT_WCC_WORKLOAD_NAME;


COMMIT;

CREATE TABLE QT_WCC_WORKLOAD_NAME( 
	NAME VARCHAR(128) NOT NULL 
,  PRIMARY KEY  ( "NAME" )
)
-- IN &tablespace
-- ORGANIZE BY ROW
;


CREATE TABLE QT_WCC_WORKLOAD( 
	WLID INTEGER  GENERATED BY DEFAULT AS IDENTITY NOT NULL,
	NAME VARCHAR(128) NOT NULL,
	CREATE_TIMESTAMP TIMESTAMP NOT NULL,
	DESCRIPTION VARCHAR(200) ,
	STATUS SMALLINT NOT NULL WITH DEFAULT 1 ,
	SUB_STATUS SMALLINT NOT NULL WITH DEFAULT 0 ,
	ANALYZE_COUNT SMALLINT NOT NULL WITH DEFAULT 0 ,
	OWNER VARCHAR(128) NOT NULL,
	LAST_EXPLAIN_TASK INTEGER ,
	LAST_UPDATE TIMESTAMP ,
	EXPLAIN_STATUS SMALLINT  WITH DEFAULT 0  
,  PRIMARY KEY  ( "WLID" )
,  FOREIGN KEY  ( "NAME" )  REFERENCES QT_WCC_WORKLOAD_NAME  ( "NAME" )  ON DELETE CASCADE)
-- IN &tablespace
-- ORGANIZE BY ROW
;


CREATE TABLE QT_WCC_WORKLOAD_SOURCE( 
	SRCID INTEGER  GENERATED BY DEFAULT AS IDENTITY NOT NULL,
	NAME VARCHAR(128) NOT NULL,
	WLID INTEGER NOT NULL,
	TYPE SMALLINT NOT NULL,
	DESCRIPTION VARCHAR(200) ,
	LAST_UPDATE_TS TIMESTAMP NOT NULL,
	QUERY_COUNT INTEGER NOT NULL WITH DEFAULT 0  
,  PRIMARY KEY  ( "SRCID" )
,  FOREIGN KEY  ( "WLID" )  REFERENCES QT_WCC_WORKLOAD  ( "WLID" )  ON DELETE CASCADE)
-- IN &tablespace
-- ORGANIZE BY ROW
;


CREATE TABLE QT_WCC_WORKLOAD_SOURCE_FILTER( 
	SRCID INTEGER NOT NULL,
	CONDITION CLOB(1048576)  
,  FOREIGN KEY  ( "SRCID" )  REFERENCES QT_WCC_WORKLOAD_SOURCE  ( "SRCID" )  ON DELETE CASCADE)
-- IN &tablespace
-- ORGANIZE BY ROW
;


CREATE TABLE QT_WCC_WORKLOAD_TASK( 
	TASKID INTEGER  GENERATED BY DEFAULT AS IDENTITY NOT NULL,
	NEXTTASK INTEGER ,
	SCHEDULED_TASKID INTEGER ,
	WLID INTEGER ,
	SRCID INTEGER ,
	TYPE SMALLINT NOT NULL,
	SUBTYPE SMALLINT ,
	STATUS VARCHAR(31) NOT NULL,
	CREATOR VARCHAR(128) NOT NULL,
	START_TIME TIMESTAMP ,
	END_TIME TIMESTAMP ,
	INTERVAL INTEGER ,
	CONSOLIDATE_EPINFO SMALLINT ,
	KEEP_STATEMENTS CHAR(1) ,
	CONSOLIDATION_TIME TIMESTAMP ,
	LAST_FIRE_TIME TIMESTAMP ,
	LAST_UPDATE_TS TIMESTAMP ,
	CONFIGURATION BLOB(2097152) ,
	EXPLAINED_STATEMENTS INTEGER ,
	ACT_START_TIME TIMESTAMP ,
	ACT_END_TIME TIMESTAMP ,
	EXPLAIN_SCHEMA VARCHAR(128) ,
	EXPLAIN_DETAIL_MODE CHAR(1) NOT NULL WITH DEFAULT 'N',
	SIMU_CATALOG_SCHEMA VARCHAR(128)
,  PRIMARY KEY  ( "TASKID" )
,  FOREIGN KEY  ( "WLID" )  REFERENCES QT_WCC_WORKLOAD  ( "WLID" )  ON DELETE CASCADE,  FOREIGN KEY  ( "SRCID" )  REFERENCES QT_WCC_WORKLOAD_SOURCE  ( "SRCID" )  ON DELETE CASCADE)
-- IN &tablespace
-- ORGANIZE BY ROW
;


CREATE TABLE QT_WCC_EVENT_HISTORY( 
	WLID INTEGER ,
	SRCID INTEGER ,
	TASKID INTEGER ,
	TYPE SMALLINT NOT NULL,
	BEGIN_TS TIMESTAMP NOT NULL,
	END_TS TIMESTAMP NOT NULL,
	STATUS CHAR(1) NOT NULL 
,  FOREIGN KEY  ( "WLID" )  REFERENCES QT_WCC_WORKLOAD  ( "WLID" )  ON DELETE CASCADE,  FOREIGN KEY  ( "SRCID" )  REFERENCES QT_WCC_WORKLOAD_SOURCE  ( "SRCID" )  ON DELETE CASCADE,  FOREIGN KEY  ( "TASKID" )  REFERENCES QT_WCC_WORKLOAD_TASK  ( "TASKID" )  ON DELETE CASCADE)
-- IN &tablespace
-- ORGANIZE BY ROW
;


CREATE TABLE QT_WCC_ERROR_MESSAGE( 
	TASKID INTEGER ,
	INSTID INTEGER ,
	WLID INTEGER ,
	SRCID INTEGER ,
	MESSAGE_ID CHAR(8) NOT NULL,
	TOKEN_1 VARCHAR(500) ,
	TOKEN_2 VARCHAR(500) ,
	TOKEN_3 VARCHAR(128) ,
	TOKEN_4 VARCHAR(128) ,
	DESCRIPTION VARCHAR(1000)  
,  FOREIGN KEY  ( "WLID" )  REFERENCES QT_WCC_WORKLOAD  ( "WLID" )  ON DELETE CASCADE)
-- IN &tablespace
-- ORGANIZE BY ROW
;


CREATE TABLE QT_WCC_STMT_TEXT( 
	STMT_TEXT_ID INTEGER  GENERATED BY DEFAULT AS IDENTITY NOT NULL,
	HASHKEY INTEGER NOT NULL WITH DEFAULT 0 ,
	STMT_LENGTH INTEGER NOT NULL,
	STMT_TEXT VARCHAR(2000) ,
	STMT_TEXT_LONG CLOB(2097152),  
	STMT_TYPE INTEGER WITH DEFAULT 0
,  PRIMARY KEY  ( "STMT_TEXT_ID" )
)
-- IN &tablespace
-- ORGANIZE BY ROW
;


CREATE TABLE QT_WCC_STMT_INSTANCE( 
	INSTID INTEGER  GENERATED BY DEFAULT AS IDENTITY NOT NULL,
	STMT_TEXT_ID INTEGER ,
	WLID INTEGER ,
	SRCID INTEGER ,
	EXPLAIN_STATUS SMALLINT  WITH DEFAULT 0 ,
	LAST_EXPLAIN_TS TIMESTAMP ,
	PKGSCHEMA VARCHAR(128) ,
	PKGNAME VARCHAR(128) ,
	STMTNO BIGINT ,
	OWNER VARCHAR(128) ,
	DEFAULT_SCHEMA VARCHAR(128) ,
	UNIQUE_ID CHAR(8) FOR BIT DATA ,
	TOTAL_SECT SMALLINT ,
	ISOLATION CHAR(2) ,
	FUNC_PATH CLOB(2048) ,
	QUERYOPT INTEGER ,
	EXPLAIN_LEVEL CHAR(1) ,
	EXPLAIN_MODE CHAR(1) ,
	EXPLICIT_BIND_TIME TIMESTAMP ,
	LAST_BIND_TIME TIMESTAMP ,
	DEGREE CHAR(5) ,
	DYNAMICRULES CHAR(1) ,
	REFRESHAGE DECIMAL(20, 6) ,
	REOPTVAR CHAR(1) ,
	PKGVERSION VARCHAR(64) ,
	OPTPROFILESCHEMA VARCHAR(128) ,
	OPTPROFILENAME VARCHAR(128) ,
	LASTUSED DATE ,
	MEMBER SMALLINT ,
	SECTION_TYPE CHAR(1) ,
	EXECUTABLE_ID VARCHAR(32) FOR BIT DATA ,
	SECTION_NUMBER BIGINT ,
	NUM_EXECUTIONS BIGINT ,
	VALID CHAR(1) ,
	STMT_TYPE_ID VARCHAR(32) ,
	STMT_PKG_CACHE_ID BIGINT ,
	MAINTAINED_TABLE_TYPE VARCHAR(128) ,
	ROUTINESCHEMA VARCHAR(128) ,
	ROUTINEMODULENAME VARCHAR(128) ,
	ROUTINENAME VARCHAR(128) ,
	ROUTINETYPE CHAR(1) ,
	SPECIFICNAME VARCHAR(128) ,
	DETERMINISTIC CHAR(1) ,
	EXTERNAL_ACTION CHAR(1) ,
	NULLCALL CHAR(1) ,
	CREATE_TIME TIMESTAMP ,
	EXPLAIN_DB_ENV BLOB(4096),
	EXPLAINED_TASKID INTEGER 
,  PRIMARY KEY  ( "INSTID" )
,  FOREIGN KEY  ( "STMT_TEXT_ID" )  REFERENCES QT_WCC_STMT_TEXT  ( "STMT_TEXT_ID" )  ON DELETE CASCADE,  FOREIGN KEY  ( "WLID" )  REFERENCES QT_WCC_WORKLOAD  ( "WLID" )  ON DELETE CASCADE,  FOREIGN KEY  ( "SRCID" )  REFERENCES QT_WCC_WORKLOAD_SOURCE  ( "SRCID" )  ON DELETE CASCADE)
-- IN &tablespace
-- ORGANIZE BY ROW
;


CREATE TABLE QT_WCC_STMT_EXPLAIN_INFO( 
	EXPLAIN_INFO_ID INTEGER  GENERATED BY DEFAULT AS IDENTITY NOT NULL,
	TASKID INTEGER ,
	INSTID INTEGER NOT NULL,
	TYPE SMALLINT ,
	SEQNO SMALLINT ,
	EXPLAIN_TIME TIMESTAMP ,
	EXPLAIN_SCHEMA VARCHAR(128) ,
	DETAIL BLOB(2097152) NOT NULL,
	COMPACT_DETAILS BLOB(2097152) ,
	HASHKEY INTEGER ,
	TOTAL_COST DOUBLE ,
	TOTAL_IO_COST DOUBLE ,
	TOTAL_CPU_COST DOUBLE ,
	TOTAL_OPERATORS SMALLINT ,
	NUM_TABLE_SCAN SMALLINT ,
	NUM_IX0_LIST_PREFETCH SMALLINT ,
	NUM_NONMATCH_INDEX SMALLINT ,
	NUM_INDEX_ONLY SMALLINT ,
	NUM_MSJOIN SMALLINT ,
	NUM_HSJOIN SMALLINT ,
	NUM_ZZJOIN SMALLINT ,
	NUM_GRPBY SMALLINT ,
	NUM_IXAND SMALLINT ,
	NUM_XANDOR SMALLINT ,
	NUM_XISCAN SMALLINT ,
	NUM_XSCAN SMALLINT ,
	NUM_TEMP SMALLINT ,
	NUM_OUTER_JOIN SMALLINT ,
	NUM_FULL_JOIN SMALLINT ,
	NUM_STAR_JOIN SMALLINT ,
	NUM_CARTESIAN_JOIN SMALLINT ,
	NUM_NLJOIN SMALLINT ,
	NUM_SORT SMALLINT  
,  PRIMARY KEY  ( "EXPLAIN_INFO_ID" )
,  FOREIGN KEY  ( "INSTID" )  REFERENCES QT_WCC_STMT_INSTANCE  ( "INSTID" )  ON DELETE CASCADE,  FOREIGN KEY  ( "TASKID" )  REFERENCES QT_WCC_WORKLOAD_TASK  ( "TASKID" )  ON DELETE CASCADE)
-- IN &tablespace
-- ORGANIZE BY ROW
;


CREATE TABLE QT_WCC_WORKLOAD_ADVISOR_INFO( 
	WLID INTEGER NOT NULL,
	STATUS VARCHAR(31) ,
	BEGIN_TS TIMESTAMP ,
	END_TS TIMESTAMP ,
	SEQNO SMALLINT ,
	BATCH_ID BIGINT ,
	EXPLAIN_VERSION_ID INTEGER ,
	DETAIL BLOB(2097152) NOT NULL,
	NAME VARCHAR(128) ,
	TYPE SMALLINT ,
	CLASSNAME VARCHAR(128)  
,  FOREIGN KEY  ( "WLID" )  REFERENCES QT_WCC_WORKLOAD  ( "WLID" )  ON DELETE CASCADE)
-- IN &tablespace
-- ORGANIZE BY ROW
;


CREATE TABLE QT_WCC_STMT_RUNTIME_METRICS( 
	INSTID INTEGER NOT NULL,
	EFFECTIVE_ISOLATION CHAR(2) ,
	PREP_TIME BIGINT ,
	TOTAL_ACT_TIME BIGINT ,
	TOTAL_CPU_TIME BIGINT ,
	POOL_READ_TIME BIGINT ,
	POOL_WRITE_TIME BIGINT ,
	DIRECT_READ_TIME BIGINT ,
	DIRECT_WRITE_TIME BIGINT ,
	LOCK_WAIT_TIME BIGINT ,
	TOTAL_SECTION_SORT_TIME BIGINT ,
	TOTAL_SECTION_SORT_PROC_TIME BIGINT ,
	TOTAL_SECTION_SORTS BIGINT ,
	ROWS_MODIFIED BIGINT ,
	ROWS_READ BIGINT ,
	ROWS_RETURNED BIGINT ,
	NUM_EXEC_WITH_METRICS BIGINT ,
	TOTAL_SORTS BIGINT ,
	NUM_COORD_EXEC BIGINT ,
	NUM_COORD_EXEC_WITH_METRICS BIGINT ,
	TOTAL_ROUTINE_TIME BIGINT ,
	TOTAL_ROUTINE_INVOCATIONS BIGINT ,
	QUERY_COST_ESTIMATE BIGINT ,
	COORD_STMT_EXEC_TIME BIGINT ,
	STMT_EXEC_TIME BIGINT ,
	DETAIL BLOB(1048576)  
,  FOREIGN KEY  ( "INSTID" )  REFERENCES QT_WCC_STMT_INSTANCE  ( "INSTID" )  ON DELETE CASCADE)
-- IN &tablespace
-- ORGANIZE BY ROW
;


CREATE TABLE QT_WCC_TEMP_CAPTURE( 
	INSTID INTEGER ,
	STMT_TEXT_ID INTEGER ,
	WLID INTEGER ,
	CAPTURE_TS TIMESTAMP NOT NULL,
	STMT_LENGTH INTEGER NOT NULL,
	STMT_TEXT CLOB(2097152) ,
	HASHKEY INTEGER NOT NULL WITH DEFAULT 0 ,
	ISOLATION CHAR(2) ,
	QUERYOPT INTEGER ,
	DEGREE CHAR(5) ,
	DYNAMICRULES CHAR(1) ,
	REFRESHAGE DECIMAL(20, 6) ,
	DEFAULT_SCHEMA VARCHAR(128) ,
	FUNC_PATH CLOB(2048) ,
	MAINTAINED_TABLE_TYPE VARCHAR(128) ,
	LAST_METRICS_UPDATE TIMESTAMP ,
	SRCID INTEGER ,
	MEMBER SMALLINT ,
	SECTION_TYPE CHAR(1) ,
	EXECUTABLE_ID VARCHAR(32) FOR BIT DATA ,
	PACKAGE_NAME VARCHAR(128) ,
	PACKAGE_SCHEMA VARCHAR(128) ,
	PACKAGE_VERSION_ID VARCHAR(128) ,
	SECTION_NUMBER BIGINT ,
	EFFECTIVE_ISOLATION CHAR(2) ,
	NUM_EXECUTIONS BIGINT ,
	NUM_EXEC_WITH_METRICS BIGINT ,
	VALID CHAR(1) ,
	STMT_TYPE_ID VARCHAR(32) ,
	STMT_PKG_CACHE_ID BIGINT ,
	PREP_TIME BIGINT ,
	TOTAL_ACT_TIME BIGINT ,
	TOTAL_CPU_TIME BIGINT ,
	POOL_READ_TIME BIGINT ,
	POOL_WRITE_TIME BIGINT ,
	DIRECT_READ_TIME BIGINT ,
	DIRECT_WRITE_TIME BIGINT ,
	LOCK_WAIT_TIME BIGINT ,
	TOTAL_SECTION_SORT_TIME BIGINT ,
	TOTAL_SECTION_SORT_PROC_TIME BIGINT ,
	TOTAL_SECTION_SORTS BIGINT ,
	ROWS_MODIFIED BIGINT ,
	ROWS_READ BIGINT ,
	ROWS_RETURNED BIGINT ,
	TOTAL_SORTS BIGINT ,
	NUM_COORD_EXEC BIGINT ,
	NUM_COORD_EXEC_WITH_METRICS BIGINT ,
	TOTAL_ROUTINE_TIME BIGINT ,
	TOTAL_ROUTINE_INVOCATIONS BIGINT ,
	QUERY_COST_ESTIMATE BIGINT ,
	COORD_STMT_EXEC_TIME BIGINT ,
	STMT_EXEC_TIME BIGINT ,
	CREATE_TIME TIMESTAMP ,
	DETAIL BLOB(1048576)  
)
-- IN &tablespace
-- ORGANIZE BY ROW
;


CREATE TABLE QT_WCC_TEMP_EXPLAIN_HANDLE( 
	INSTID INTEGER NOT NULL,
	WLID INTEGER NOT NULL,
	TASKID INTEGER ,
	EXPLAIN_REQUESTER VARCHAR(128) ,
	EXPLAIN_TIME TIMESTAMP ,
	SOURCE_NAME VARCHAR(128) ,
	SOURCE_SCHEMA VARCHAR(128) ,
	SOURCE_VERSION VARCHAR(64) ,
	STMTNO BIGINT ,
	SECTNO BIGINT  
,  FOREIGN KEY  ( "INSTID" )  REFERENCES QT_WCC_STMT_INSTANCE  ( "INSTID" )  ON DELETE CASCADE,  FOREIGN KEY  ( "WLID" )  REFERENCES QT_WCC_WORKLOAD  ( "WLID" )  ON DELETE CASCADE,  FOREIGN KEY  ( "TASKID" )  REFERENCES QT_WCC_WORKLOAD_TASK  ( "TASKID" )  ON DELETE CASCADE)
-- IN &tablespace
-- ORGANIZE BY ROW
;


CREATE TABLE QT_WCC_STMT_DEPENDENT_OBJECT( 
	EXPLAIN_INFO_ID INTEGER NOT NULL,
	INSTID INTEGER NOT NULL,
	TYPE CHAR(1) ,
	TABSCHEMA VARCHAR(128) ,
	TABNAME VARCHAR(128) ,
	INDSCHEMA VARCHAR(128) ,
	INDNAME VARCHAR(128)  
,  FOREIGN KEY  ( "INSTID" )  REFERENCES QT_WCC_STMT_INSTANCE  ( "INSTID" )  ON DELETE CASCADE,  FOREIGN KEY  ( "EXPLAIN_INFO_ID" )  REFERENCES QT_WCC_STMT_EXPLAIN_INFO  ( "EXPLAIN_INFO_ID" )  ON DELETE CASCADE)
-- IN &tablespace
-- ORGANIZE BY ROW
;

CREATE TABLE QT_WAPC_SESSIONS(
		SESSIONID INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 NO CYCLE CACHE 20 NO ORDER ), 
		WLID INTEGER, 
		START_TIME TIMESTAMP, 
		END_TIME TIMESTAMP, 
		USER_ID VARCHAR(128), 
		CLIENT_ID VARCHAR(48), 
		STATUS CHAR(1), 
		METADATA VARCHAR(3000), 
		DONE_RATIO DOUBLE,
		PRIMARY KEY  ( "SESSIONID" ),
		FOREIGN KEY	("WLID") REFERENCES QT_WCC_WORKLOAD ("WLID")	ON DELETE CASCADE
	)
-- IN &tablespace
-- ORGANIZE BY ROW
;


-- If your database is v9.5.x, uncomment the following CREATE statement, and comment out the one following this. 
--CREATE TABLE QT_WAPC_SESSIONS_RESULT (
--		SESSIONID INTEGER NOT NULL, 
--		SEQNO INTEGER, 
--		RESULT BLOB(2097152),
--		FOREIGN KEY	("SESSIONID") REFERENCES QT_WAPC_SESSIONS ("SESSIONID")	ON DELETE CASCADE
--	)
---- IN &tablespace
--;
CREATE TABLE QT_WAPC_SESSIONS_RESULT (
		SESSIONID INTEGER NOT NULL, 
		SEQNO INTEGER, 
		RESULT BLOB(2097152) INLINE LENGTH 164,
		FOREIGN KEY	("SESSIONID") REFERENCES QT_WAPC_SESSIONS ("SESSIONID")	ON DELETE CASCADE
	)
-- IN &tablespace
-- ORGANIZE BY ROW
;

CREATE TABLE QT_WAPC_SESSION_EXCEPTIONS (
		SESSIONID INTEGER NOT NULL, 
		TYPE CHAR(1), 
		MESSAGE_ID CHAR(8), 
		OCCUR_TIME TIMESTAMP, 
		TOKEN_1 VARCHAR(500), 
		TOKEN_2 VARCHAR(500), 
		TOKEN_3 VARCHAR(500), 
		TOKEN_4 VARCHAR(500),
		FOREIGN KEY ("SESSIONID") REFERENCES QT_WAPC_SESSIONS ("SESSIONID") ON DELETE CASCADE
	)
-- IN &tablespace
-- ORGANIZE BY ROW
;

CREATE SEQUENCE SYSTOOLS.QT_WCC_TUNING_BATCH_ID AS BIGINT START WITH 1 INCREMENT BY 1 NO MAXVALUE NO CYCLE ORDER;

CREATE  INDEX QT_WCC_WL_IX01 ON QT_WCC_WORKLOAD ("NAME");


CREATE  INDEX QT_WCC_WORKLOAD_SOURCE_IX01 ON QT_WCC_WORKLOAD_SOURCE ("WLID", "SRCID", "TYPE");


CREATE  INDEX QT_WCC_WORKLOAD_SOURCE_FILTER_IX01 ON QT_WCC_WORKLOAD_SOURCE_FILTER ("SRCID");


CREATE  INDEX QT_WCC_WORKLOAD_TASK_IX01 ON QT_WCC_WORKLOAD_TASK ("WLID", "STATUS");


CREATE  INDEX QT_WCC_WORKLOAD_TASK_IX02 ON QT_WCC_WORKLOAD_TASK ("WLID", "TYPE");


CREATE  INDEX QT_WCC_EVEN_HISTORY_IX01 ON QT_WCC_EVENT_HISTORY ("WLID", "BEGIN_TS", "END_TS");


CREATE  INDEX QT_WCC_ERROR_MESSAGE_IX01 ON QT_WCC_ERROR_MESSAGE ("WLID", "TASKID", "INSTID");


CREATE  INDEX QT_WCC_STMT_TEXT_IX01 ON QT_WCC_STMT_TEXT ("HASHKEY");


CREATE  INDEX QT_WCC_STMT_INSTANCE_IX01 ON QT_WCC_STMT_INSTANCE ("STMT_TEXT_ID", "INSTID");


CREATE  INDEX QT_WCC_STMT_INSTANCE_IX02 ON QT_WCC_STMT_INSTANCE ("WLID", "INSTID");


CREATE  INDEX QT_WCC_STMT_INSTANCE_IX03 ON QT_WCC_STMT_INSTANCE ("WLID", "EXPLAIN_STATUS" DESC );


CREATE  INDEX QT_WCC_STMT_EXPLAIN_INFO_IX01 ON QT_WCC_STMT_EXPLAIN_INFO ("INSTID", "EXPLAIN_INFO_ID");


CREATE  INDEX QT_WCC_STMT_EXPLAIN_INFO_IX02 ON QT_WCC_STMT_EXPLAIN_INFO ("INSTID", "TASKID", "TYPE");


CREATE  INDEX QT_WCC_WORKLOAD_ADVISOR_INFO_IX01 ON QT_WCC_WORKLOAD_ADVISOR_INFO ("WLID", "NAME", "BEGIN_TS");


CREATE  INDEX QT_WCC_STMT_RUNTIME_METRICS_IX01 ON QT_WCC_STMT_RUNTIME_METRICS ("INSTID");


CREATE  INDEX QT_WCC_TEMP_CAPTURE_IX01 ON QT_WCC_TEMP_CAPTURE ("CAPTURE_TS", "INSTID");


CREATE  INDEX QT_WCC_TEMP_CAPTURE_IX02 ON QT_WCC_TEMP_CAPTURE ("SRCID", "WLID");


CREATE  INDEX QT_WCC_TEMP_EXPLAIN_HANDLE_IX01 ON QT_WCC_TEMP_EXPLAIN_HANDLE ("WLID", "INSTID");


CREATE  INDEX QT_WCC_STMT_DEPENDENT_OBJECT_IX01 ON QT_WCC_STMT_DEPENDENT_OBJECT ("TABSCHEMA", "TABNAME");


CREATE  INDEX QT_WCC_STMT_DEPENDENT_OBJECT_IX02 ON QT_WCC_STMT_DEPENDENT_OBJECT ("INDSCHEMA", "INDNAME");


CREATE  INDEX QT_WCC_STMT_DEPENDENT_OBJECT_IX03 ON QT_WCC_STMT_DEPENDENT_OBJECT ("INSTID", "EXPLAIN_INFO_ID");



COMMIT;
